@@ -20,7 +20,7 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.10026';
+our $VERSION = '0.12026';
 
 $VERSION =~ /([0-9]{2})$/;
 my $compat_version = $1;
@@ -83,6 +83,16 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
 
     @DEFAULT_SEARCH_PATH = split $Config{path_sep}, $ENV{PKG_CONFIG_LIBDIR};
 
+} elsif($^O eq 'msys') {
+
+    # MSYS2 seems to actually set PKG_CONFIG_PATH in its /etc/profile
+    # god bless it.  But.  The defaults if you unset the environment
+    # variable are different
+    @DEFAULT_SEARCH_PATH = qw(
+        /usr/lib/pkgconfig
+        /usr/share/pkgconfig
+    );
+
 } elsif($^O eq 'solaris' && $Config{ptrsize} == 8) {
 
     @DEFAULT_SEARCH_PATH = qw(
@@ -413,7 +423,7 @@ struct(
      # will be listed first
      'libs_deplist' => '*%',
 
-     # cummulative cflags and ldflags
+     # cumulative cflags and ldflags
      'ldflags'   => '*@',
      'cflags'    => '*@',
 
@@ -707,7 +717,7 @@ sub parse_line {
     #perl variables can't have '.' in them:
     $field =~ s/\./DOT/g;
     
-    #remove quoutes from field names
+    #remove quotes from field names
     $field =~ s/['"]//g;
     
 
@@ -726,7 +736,7 @@ sub parse_line {
     $value = join ' ', map { s/(["'])/\\$1/g; "'$_'" } shellwords $value
       if $value =~ /[\\"']/;
     
-    #quoute the value string, unless quouted already
+    #quote the value string, unless quoted already
     $value = "\"$value\"";
     
     #get existent variables from our hash:
@@ -1090,6 +1100,9 @@ GetOptions(
     'h|help|?'      => \my $WantHelp
 ) or pod2usage(@POD_USAGE_OPTIONS);
 
+if($^O eq 'msys' && !$ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
+    $UseStatic = 1;
+}
 
 if($WantHelp) {
     pod2usage(@POD_USAGE_OPTIONS, -exitval => 0);
@@ -1278,7 +1291,7 @@ PkgConfig - Pure-Perl Core-Only replacement for pkg-config
 
     $ ppkg-config --libs --cflags --static gio-2.0
 
-    #outputs (lines artifically broken up for readability):
+    #outputs (lines artificially broken up for readability):
     # -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include
     # -pthread -lgio-2.0 -lz -lresolv -lgobject-2.0
     # -lgmodule-2.0 -ldl -lgthread-2.0 -pthread -lrt -lglib-2.0
@@ -1437,7 +1450,7 @@ C<--silence-errors>
 
 =head4 --short-errors
 
-Ignored, but recognized for compatability.
+Ignored, but recognized for compatibility.
 
 =head4 --errors-to-stdout
 
@@ -1482,7 +1495,7 @@ a working version that implements this feature.
 
 =head4 I<< PkgConfig->find >>
 
-    my $result = PkgConfig->find($libary, %options);
+    my $result = PkgConfig->find($library, %options);
 
 Find a library and return a result object.
 C<$library> can be either a single name of a library, or a reference to an
@@ -1709,6 +1722,8 @@ Other contributors include:
 
 =item Breno G. de Oliveira (garu)
 
+=item Gregor Herrmann
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
